<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Config\Asset
 * @copyright   Copyright (c) 2022, WeCodeArt Framework
 * @since 		5.4.5
 * @version		5.4.5
 */

namespace WeCodeArt\Config\Traits;

defined( 'ABSPATH' ) || exit();

/**
 * Base Trait Class for implementing make_handle()
 */
trait Asset {
	/**
	 * Make a script handle from the classname
	 *
	 * @since	5.4.5
 	 * @version	5.4.5
	 *
	 * @param	string 	$name
	 *
	 * @return 	string
	 */
	protected function make_handle( $name = '', $namespace = __CLASS__ ) {
		$handle = strtolower( str_replace( '\\', '-', $namespace ) );
		$handle = $name ? $handle . '-' . $name : $handle;
		
		return sanitize_html_class( $handle );
	}

	/**
	 * Retrieve an asset if path structure is the same as class
	 *
	 * @since	5.4.5
 	* @version	5.4.5
	 *
	 * @param	string 	$type
	 * @param	string 	$name
	 *
	 * @return 	string
	 */
	protected function get_asset( string $type, string $name = __CLASS__ ) {
	 	return wecodeart_asset( $type, strtolower( str_replace( '\\', '-', $name ) ) );
	}
}